# Freeproxy [![python](https://img.shields.io/badge/Python-universal-white.svg?style=style=flat-square)](https://www.python.org/downloads/) ![version](https://img.shields.io/badge/Version-v1_(stable)-blue.svg?style=style=flat-square) [![license](https://img.shields.io/badge/License-GPL_3-orange.svg?style=style=flat-square)](https://github.com/UltimateHacke/XSStrike/blob/master/license.txt)

Freeproxy package is a python module for dump proxies.</br>
It supports python3 and can be install via pip as follows.</br>

Installation
```
pip install freeproxeis
```
or 
```
git clone https://github.com/iamkamleshrangi/freeproxies.git
cd freeproxies 
pip install -r requirements.txt
```

## Documentation

usage

```
import freeproxies

one_proxies = freeproxies.get_one() #Give you single proxy
more_proxies = freeproxies.get_more() #Give you list of 300 proxies.
```


